@@ -11,6 +11,7 @@ lazy_static! {
         let mut m: HashMap<String, f64> = vec![
             ("1INCH/USDT", 1_f64),
             ("AAVE/USDT", 0.01_f64),
+            ("ACA/USDT", 1_f64),
             ("ACH/USDT", 1_f64),
             ("ADA/USDT", 1_f64),
             ("AGLD/USDT", 0.1_f64),
@@ -19,9 +20,11 @@ lazy_static! {
             ("ALGO/USDT", 1_f64),
             ("ALICE/USDT", 0.1_f64),
             ("ALPHA/USDT", 1_f64),
+            ("ANC/USDT", 1_f64),
             ("ANKR/USDT", 1_f64),
             ("ANT/USDT", 1_f64),
             ("ANY/USDT", 0.1_f64),
+            ("API3/USDT", 1_f64),
             ("APX/USDT", 10_f64),
             ("AR/USDT", 0.1_f64),
             ("ARPA/USDT", 1_f64),
@@ -72,6 +75,7 @@ lazy_static! {
             ("DOGE/USDT", 100_f64),
             ("DORA/USDT", 0.1_f64),
             ("DOT/USDT", 0.1_f64),
+            ("DUSK/USDT", 10_f64),
             ("DYDX/USDT", 1_f64),
             ("EDEN/USDT", 1_f64),
             ("EGLD/USDT", 0.1_f64),
@@ -90,7 +94,9 @@ lazy_static! {
             ("FTM/USDT", 1_f64),
             ("FTT/USDT", 0.1_f64),
             ("GALA/USDT", 10_f64),
+            ("GDO/USDT", 10000000_f64),
             ("GODS/USDT", 1_f64),
+            ("GOLDFINCH/USDT", 1_f64),
             ("GRT/USDT", 1_f64),
             ("GTC/USDT", 0.1_f64),
             ("HBAR/USDT", 1_f64),
@@ -108,6 +114,8 @@ lazy_static! {
             ("IOTX/USDT", 1_f64),
             ("JASMY/USDT", 10_f64),
             ("JOE/USDT", 1_f64),
+            ("JST/USDT", 100_f64),
+            ("JUSTICE/USDT", 1000_f64),
             ("KAVA/USDT", 0.1_f64),
             ("KEEP/USDT", 1_f64),
             ("KISHU/USDT", 1000000000_f64),
@@ -117,6 +125,7 @@ lazy_static! {
             ("LINA/USDT", 1_f64),
             ("LINK/USDT", 0.1_f64),
             ("LIT/USDT", 0.1_f64),
+            ("LOOKS/USDT", 1_f64),
             ("LPT/USDT", 0.1_f64),
             ("LRC/USDT", 1_f64),
             ("LTC/USDT", 0.01_f64),
@@ -144,15 +153,20 @@ lazy_static! {
             ("PEOPLE/USDT", 10_f64),
             ("PIT/USDT", 1000000000_f64),
             ("PLA/USDT", 1_f64),
+            ("POKT/USDT", 1_f64),
             ("PSP/USDT", 1_f64),
             ("QTUM/USDT", 0.1_f64),
             ("RACA/USDT", 1000_f64),
             ("RAY/USDT", 0.1_f64),
             ("REEF/USDT", 1_f64),
             ("RNDR/USDT", 1_f64),
+            ("ROSE/USDT", 10_f64),
             ("RSR/USDT", 1_f64),
+            ("RSS3/USDT", 10_f64),
+            ("RVN/USDT", 10_f64),
             ("SAND/USDT", 1_f64),
             ("SC/USDT", 1_f64),
+            ("SCRT/USDT", 1_f64),
             ("SDN/USDT", 0.1_f64),
             ("SFP/USDT", 1_f64),
             ("SHIB/USDT", 1000_f64),
@@ -178,10 +192,15 @@ lazy_static! {
             ("TRVL/USDT", 1_f64),
             ("TRX/USDT", 10_f64),
             ("UMA/USDT", 0.1_f64),
+            ("UMEE/USDT", 10_f64),
             ("UNI/USDT", 0.1_f64),
             ("VET/USDT", 1_f64),
+            ("VRA/USDT", 100_f64),
             ("WAVES/USDT", 0.1_f64),
             ("WAXP/USDT", 10_f64),
+            ("WOO/USDT", 1_f64),
+            ("WRLD/USDT", 10_f64),
+            ("X2Y2/USDT", 1_f64),
             ("XCH/USDT", 0.01_f64),
             ("XEC/USDT", 10000_f64),
             ("XEM/USDT", 1_f64),
